Stan Math Library: stan/math/fwd/mat/fun/trace_gen_quad_form.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
trace_gen_quad_form.hpp File Reference
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/fwd/mat/fun/multiply.hpp>`
`#include <stan/math/prim/mat/fun/trace.hpp>`
`#include <stan/math/prim/mat/fun/multiply.hpp>`
`#include <stan/math/prim/mat/fun/transpose.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int RD, int CD, int RA, int CA, int RB, int CB, typename T >
fvar< T > | stan::math::trace_gen_quad_form (const Eigen::Matrix< fvar< T >, RD, CD > &D, const Eigen::Matrix< fvar< T >, RA, CA > &A, const Eigen::Matrix< fvar< T >, RB, CB > &B)

[ Stan Home Page ] © 2011–2016, Stan Development Team.